﻿using UnityEngine;
using System.Collections;

public class BallScript : MonoBehaviour {

	public float minimumSpeed = 500;
	private BallExplosion ballExplosion;
	private GameObject explosionObject;

	public delegate void BallEventHandler(GameObject ball, GameObject collision);
	public static event BallEventHandler onBallCollideWithWall;
	public static event BallEventHandler onBallCollideWithBrick;
	public static event BallEventHandler onBallCollideWithGround;
	public static event BallEventHandler onBallCollideWithPaddle;

	private void removeBallFromGame(ParticleSystem explosionSystem)
	{
		Destroy(gameObject);
	}

	public void OnEnable()
	{
		ballExplosion.OnBallExplosionDidFinish += removeBallFromGame;
	}
	
	public void OnDisable()
	{
		ballExplosion.OnBallExplosionDidFinish -= removeBallFromGame;
	}

	void Awake() {
		explosionObject = transform.FindChild("Explosion").gameObject;
		ballExplosion = explosionObject.GetComponent<BallExplosion>();
	}

	void Update () {
		if (Input.GetKeyDown(KeyCode.Space)) {
			if (transform.parent != null)
			{
				LaunchBall();
			}
		}

	}

	public void Explode()
	{
		rigidbody.velocity = Vector3.zero;
		renderer.enabled = false;
		collider.enabled = false;
		explosionObject.SetActive(true);
		BallExplosion ballExplosionScript = ballExplosion.GetComponent<BallExplosion>();
		ballExplosionScript.PlayExplosion();
	}

	public void LaunchBall()
	{
		if (transform.parent)
		{
			transform.parent = null;
		}
		
		rigidbody.isKinematic = false;
		rigidbody.AddForce(minimumSpeed * Input.GetAxis( "Horizontal" ) * 2, minimumSpeed, 0);
	}

	void OnCollisionEnter(Collision collision) {
		if (collision.gameObject.tag.Equals("Wall"))
		{
			if (onBallCollideWithWall != null)
			{
				onBallCollideWithWall(transform.gameObject, collision.gameObject);
			}
		}
		if (collision.gameObject.tag.Equals("Paddle"))
		{
			if (onBallCollideWithPaddle != null)
			{
				onBallCollideWithPaddle(transform.gameObject, collision.gameObject);
			}
		}
		if (collision.gameObject.tag == "Brick") {
			if (onBallCollideWithBrick != null) {
				onBallCollideWithBrick(gameObject, collider.gameObject);
			}
		}
		if (collision.gameObject.tag.Equals("Ground"))
		{
			if (onBallCollideWithGround != null)
			{
				onBallCollideWithGround(transform.gameObject, collision.gameObject);
			}
		}
	}

}
