﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class GameManager : MonoBehaviour {

	public GameObject[] columns;
	public GameObject soundEffectsObject;
	public GameObject paddle;
	public GameObject ballPrefab;
	public int firstBallCombo = 10;
	public int secondBallCombo = 20;
	public int combosPerExtraBall = 10;
	public int brickPoint = 10;
	public List<GameObject> ballsInPlay = new List<GameObject>();

	private int combo = 1;
	private SoundEffects soundEffects;
	private GameObject previousCollisionObject = null;
	private bool columnsReady = false;

	public void OnEnable() {
		BallScript.onBallCollideWithBrick += this.CollideWithBrick;
		BallScript.onBallCollideWithGround += this.CollideWithGround;
		BallScript.onBallCollideWithPaddle += this.CollideWithPaddle;
	}
	
	public void OnDisable() {
		BallScript.onBallCollideWithBrick -= this.CollideWithBrick;
		BallScript.onBallCollideWithGround -= this.CollideWithGround;
		BallScript.onBallCollideWithPaddle -= this.CollideWithPaddle;
	}


	public void CollideWithBrick(GameObject Ball, GameObject brick)
	{
		previousCollisionObject = brick;
	}

	public void CollideWithPaddle(GameObject BallScript, GameObject paddle)
	{
		if (previousCollisionObject != null)
		{
			combo += 1;
			if (combo == firstBallCombo && ballsInPlay.Count == 1 || combo == secondBallCombo && ballsInPlay.Count == 2)
			{
				spawnBall();
				launchBall();
				soundEffects.PlayExtraBallSound();
			}
			
		}
	}

	private void launchBall()
	{
		GameObject spawnPoint = paddle.transform.Find ("SpawnPoint").gameObject;
		Transform ball = spawnPoint.transform.Find("Ball");
		if (ball != null)
		{
			GameObject queuedBall = ball.gameObject;
			BallScript ballScript = queuedBall.GetComponent<BallScript>();
			ballScript.LaunchBall();
		}
	}
	
	private IEnumerator enableColumns() {
		for (int i=0; i < columns.Length; i++) {
			GameObject column = columns[i];
			column.SetActive(true);
			yield return new WaitForSeconds(.2f);
		}
		StopCoroutine("enableColumns");
		columnsReady = true;
	}

	void Awake() {
		soundEffects = soundEffectsObject.GetComponent<SoundEffects>();
		StartCoroutine("enableColumns");
		soundEffects.PlayRespawnSound();
	}

	public void CollideWithGround(GameObject ball, GameObject block)
	{
		previousCollisionObject = null;
		BallScript ballScript = ball.GetComponent<BallScript>();
		ballScript.Explode();
		combo = 0;
	}

	private void spawnBall()
	{
		GameObject spawnPoint = paddle.transform.Find ("SpawnPoint").gameObject;
		GameObject newBall = Instantiate(ballPrefab, spawnPoint.transform.position, Quaternion.identity) as GameObject;
		newBall.transform.localScale = Vector3.one;
		newBall.transform.parent = spawnPoint.transform;
		newBall.transform.name = "Ball";
		newBall.rigidbody.isKinematic = true;
		
		ballsInPlay.Add(newBall);
	}

	// Use this for initialization
	void Start () {
	
	}
	
	// Update is called once per frame
	void Update () {
		if (Input.GetKey(KeyCode.Space))
		{
			launchBall();
		}
		if (columnsReady == true && ballsInPlay.Count == 0)
		{
			spawnBall();
		}
	}
}
