﻿using UnityEngine;
using System.Collections;

public class SoundEffects : MonoBehaviour 
{
	public AudioClip brickCollision;
	public AudioClip wallCollision;
	public AudioClip paddleCollision;
	public AudioClip extraBall;
	public AudioClip spawnBricks;
	public AudioClip ballExplosion;
	
	private AudioSource audioSource;
	
	public void Awake()
	{
		audioSource = GetComponent<AudioSource>();
	}
	
	public void OnEnable()
	{
		BallScript.onBallCollideWithWall += this.CollideWithWall;
		BallScript.onBallCollideWithBrick += this.CollideWithBrick;
		BallScript.onBallCollideWithGround += this.CollideWithGround;
		BallScript.onBallCollideWithPaddle += this.CollideWithPaddle;
	}
	
	public void OnDisable()
	{
		BallScript.onBallCollideWithWall -= this.CollideWithWall;
		BallScript.onBallCollideWithBrick -= this.CollideWithBrick;
		BallScript.onBallCollideWithGround -= this.CollideWithGround;
		BallScript.onBallCollideWithPaddle -= this.CollideWithPaddle;
	}

	public void CollideWithPaddle(GameObject ball, GameObject wall)
	{
		audioSource.PlayOneShot(paddleCollision);
	}

	public void CollideWithGround(GameObject ball, GameObject wall)
	{
		audioSource.PlayOneShot(ballExplosion);
	}
	
	public void CollideWithWall(GameObject ball, GameObject wall)
	{
		audioSource.PlayOneShot(wallCollision);
	}

	public void PlayExtraBallSound()
	{
		audioSource.PlayOneShot(extraBall);
	}
	
	public void CollideWithBrick(GameObject ball, GameObject block)
	{
		audioSource.PlayOneShot(brickCollision);
	}
	
	public void PlayRespawnSound()
	{
		audioSource.audio.clip = spawnBricks;
		audioSource.PlayDelayed(.4f);
	}
	
	public void PlayBallExplosion()
	{
		audioSource.PlayOneShot(ballExplosion);
	}
	
}
